// Timer is based on these with changes

// Build a React Timer Component Using Hooks by James King
// https://upmostly.com/tutorials/build-a-react-timer-component-using-hooks

import React, { useState, useEffect } from 'react';

const Timer = () => {
  const [startTime, setStartTime] = useState(0);
  const [elapsedTime, setElapsedTime] = useState("0.0");
  const [isActive, setIsActive] = useState(false);

  function toggle() {
    setStartTime(new Date());
    setIsActive(!isActive);
  }

  function stop() {
    setStartTime(0);
    setElapsedTime("0.0");
    setIsActive(false);
  }

  useEffect(() => {
    let interval = null;
    if (isActive) {
      interval = setInterval(() => {
        let epochElapsedTime = new Date() - startTime;
        
        let elapsedTime = {
          minutes: new Date(epochElapsedTime).getMinutes(),
          seconds: new Date(epochElapsedTime).getSeconds(),
          milliseconds: new Date(epochElapsedTime).getMilliseconds()
        };
        
        if(elapsedTime.minutes !== 0){
          setElapsedTime(elapsedTime.minutes + ":" + elapsedTime.seconds + "." + elapsedTime.milliseconds);
        } else {
          setElapsedTime(elapsedTime.seconds + "." + elapsedTime.milliseconds);
        }
      }, 10);
    } else if (!isActive && startTime !== 0 && elapsedTime !== "0.0") {
      clearInterval(interval);
    }
    return () => clearInterval(interval);
  }, [isActive, startTime, elapsedTime]);

  return (
    <div className="timer">
      <div className="time">
        {elapsedTime}
      </div>
      <div className="row">
        <button className={`button button-primary button-primary-${isActive ? 'active' : 'inactive'}`} onClick={toggle}>
        {isActive ? 'Pause' : 'Start'}
        </button>
        <button className="button" onClick={stop}>
        Stop
        </button>
      </div>
    </div>
  );
};

export default Timer;
